@@ -17,11 +17,6 @@
 #include <QTimer>
 
 KJobPrivate::KJobPrivate()
-    : q_ptr(nullptr), uiDelegate(nullptr), error(KJob::NoError),
-      progressUnit(KJob::Bytes), percentage(0),
-      speedTimer(nullptr), eventLoop(nullptr),
-      capabilities(KJob::NoCapabilities),
-      suspended(false), isAutoDelete(true), isFinished(false)
 {
 }
 
@@ -44,6 +39,7 @@ KJob::KJob(KJobPrivate &dd, QObject *parent)
 KJob::~KJob()
 {
     if (!d_ptr->isFinished) {
+        d_ptr->isFinished = true;
         emit finished(this, QPrivateSignal());
     }
 
@@ -83,6 +79,7 @@ bool KJob::isSuspended() const
 void KJob::finishJob(bool emitResult)
 {
     Q_D(KJob);
+    Q_ASSERT(!d->isFinished);
     d->isFinished = true;
 
     if (d->eventLoop) {
@@ -103,10 +100,18 @@ void KJob::finishJob(bool emitResult)
 
 bool KJob::kill(KillVerbosity verbosity)
 {
-    if (doKill()) {
-        setError(KilledJobError);
+    Q_D(KJob);
+    if (d->isFinished) {
+        return true;
+    }
 
-        finishJob(verbosity != Quietly);
+    if (doKill()) {
+        // A subclass can (but should not) call emitResult() or kill()
+        // from doKill() and thus set isFinished to true.
+        if (!d->isFinished) {
+            setError(KilledJobError);
+            finishJob(verbosity != Quietly);
+        }
         return true;
     } else {
         return false;
@@ -222,6 +227,11 @@ unsigned long KJob::percent() const
     return d_func()->percentage;
 }
 
+bool KJob::isFinished() const
+{
+    return d_func()->isFinished;
+}
+
 void KJob::setError(int errorCode)
 {
     Q_D(KJob);
@@ -266,6 +276,12 @@ void KJob::setTotalAmount(Unit unit, qulonglong amount)
     }
 }
 
+void KJob::setProgressUnit(Unit unit)
+{
+    Q_D(KJob);
+    d->progressUnit = unit;
+}
+
 void KJob::setPercent(unsigned long percentage)
 {
     Q_D(KJob);
@@ -277,7 +293,9 @@ void KJob::setPercent(unsigned long percentage)
 
 void KJob::emitResult()
 {
-    finishJob(true);
+    if (!d_func()->isFinished) {
+        finishJob(true);
+    }
 }
 
 void KJob::emitPercent(qulonglong processedAmount, qulonglong totalAmount)
