@@ -1,27 +1,14 @@
 /*
- * This file is part of the KDE Libraries
- * Copyright (C) 2000 Espen Sand (espen@kde.org)
- * Copyright (C) 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
- * Copyright (C) 2010 Teo Mrnjavac <teo@kde.org>
- * Copyright (C) 2013 David Faure <faure+bluesystems@kde.org>
- * Copyright (C) 2017 Harald Sitter <sitter@kde.org>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
- *
- */
+    This file is part of the KDE Libraries
+
+    SPDX-FileCopyrightText: 2000 Espen Sand <espen@kde.org>
+    SPDX-FileCopyrightText: 2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    SPDX-FileCopyrightText: 2010 Teo Mrnjavac <teo@kde.org>
+    SPDX-FileCopyrightText: 2013 David Faure <faure+bluesystems@kde.org>
+    SPDX-FileCopyrightText: 2017 Harald Sitter <sitter@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #ifndef KABOUTDATA_H
 #define KABOUTDATA_H
@@ -456,18 +443,29 @@ public:
      */
     static void setApplicationData(const KAboutData &aboutData);
 
+// BUILD, not ENABLE, as producers need to support the registry for backward-compat
+#if KCOREADDONS_BUILD_DEPRECATED_SINCE(5, 76)
     /**
      * Register the KAboutData information for a plugin.
      * Call this from the constructor of the plugin.
      * This will register the plugin's @p aboutData under the component name
      * that was set in @p aboutData.
+     * @deprecated Since 5.76. The central registry is to be removed in the future
+     * in favour of plugin type specific local registries, using KPluginMetaData.
      */
+    KCOREADDONS_DEPRECATED_VERSION(5, 76, "See API docs")
     static void registerPluginData(const KAboutData &aboutData);
+#endif
 
+#if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 76)
     /**
      * Return the KAboutData for the given plugin identified by @p componentName.
+     * @deprecated Since 5.76. The central registry is to be removed in the future
+     * in favour of plugin type specific local registries, using KPluginMetaData.
      */
+    KCOREADDONS_DEPRECATED_VERSION(5, 76, "See API docs")
     static KAboutData *pluginData(const QString &componentName);
+#endif
 
 #if KCOREADDONS_ENABLE_DEPRECATED_SINCE(5, 65)
     /**
